pitchtools.calculate_harmonic_counterpoint_interval_from_named_chromatic_pitch_to_named_chromatic_pitch
=======================================================================================================

.. autofunction:: abjad.tools.pitchtools.calculate_harmonic_counterpoint_interval_from_named_chromatic_pitch_to_named_chromatic_pitch.calculate_harmonic_counterpoint_interval_from_named_chromatic_pitch_to_named_chromatic_pitch
